package com.djhk.uav.uav.mapper;



import com.djhk.uav.uav.domain.ThreedModelInfo;
import com.djhk.uav.uav.domain.ThreedModelInfoVo;

import java.util.List;

/**
 * 模型Mapper接口
 * 
 * @author ruoyi
 * @date 2023-07-27
 */
public interface ThreedModelInfoMapper 
{
    /**
     * 查询模型
     * 
     * @param modelId 模型主键
     * @return 模型
     */
    public ThreedModelInfo selectThreedModelInfoByModelId(Long modelId);

    /**
     * 查询模型列表
     * 
     * @param threedModelInfoVo 模型
     * @return 模型集合
     */
    public List<ThreedModelInfo> selectThreedModelInfoList(ThreedModelInfoVo threedModelInfoVo);

    /**
     * 新增模型
     * 
     * @param threedModelInfo 模型
     * @return 结果
     */
    public int insertThreedModelInfo(ThreedModelInfo threedModelInfo);

    /**
     * 修改模型
     * 
     * @param threedModelInfo 模型
     * @return 结果
     */
    public int updateThreedModelInfo(ThreedModelInfo threedModelInfo);

    /**
     * 删除模型
     * 
     * @param modelId 模型主键
     * @return 结果
     */
    public int deleteThreedModelInfoByModelId(Long modelId);

    /**
     * 批量删除模型
     * 
     * @param modelIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteThreedModelInfoByModelIds(Long[] modelIds);

    List<ThreedModelInfo> selectThreedModelInfoAllList();

    List<ThreedModelInfo> selectThreedModelInfoLists(Long deptId);
}
